@@ -1,5 +1,5 @@
 /* cp.c  -- file copying (main routines)
-   Copyright (C) 1989-1991, 1995-2012 Free Software Foundation, Inc.
+   Copyright (C) 1989-2012 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -49,7 +49,7 @@
     }							\
   while (0)
 
-/* The official name of this program (e.g., no `g' prefix).  */
+/* The official name of this program (e.g., no 'g' prefix).  */
 #define PROGRAM_NAME "cp"
 
 #define AUTHORS \
@@ -150,8 +150,7 @@ void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-             program_name);
+    emit_try_help ();
   else
     {
       printf (_("\
@@ -247,7 +246,7 @@ fails, or if --reflink=auto is specified, fall back to a standard copy.\n\
 "), stdout);
       fputs (_("\
 \n\
-The backup suffix is `~', unless set with --suffix or SIMPLE_BACKUP_SUFFIX.\n\
+The backup suffix is '~', unless set with --suffix or SIMPLE_BACKUP_SUFFIX.\n\
 The version control method may be selected via the --backup option or through\n\
 the VERSION_CONTROL environment variable.  Here are the values:\n\
 \n\
@@ -280,10 +279,10 @@ regular file.\n\
    ATTR_LIST is a null-terminated linked list of structures that
    indicates the end of the filename of each intermediate directory
    in CONST_DST_NAME that may need to have its attributes changed.
-   The command `cp --parents --preserve a/b/c d/e_dir' changes the
+   The command 'cp --parents --preserve a/b/c d/e_dir' changes the
    attributes of the directories d/e_dir/a and d/e_dir/a/b to match
    the corresponding source directories regardless of whether they
-   existed before the `cp' command was given.
+   existed before the 'cp' command was given.
 
    Return true if the parent of CONST_DST_NAME and any intermediate
    directories specified by ATTR_LIST have the proper permissions
@@ -295,7 +294,7 @@ re_protect (char const *const_dst_name, size_t src_offset,
 {
   struct dir_attr *p;
   char *dst_name;		/* A copy of CONST_DST_NAME we can change. */
-  char *src_name;		/* The source name in `dst_name'. */
+  char *src_name;		/* The source name in 'dst_name'. */
 
   ASSIGN_STRDUPA (dst_name, const_dst_name);
   src_name = dst_name + src_offset;
@@ -452,7 +451,7 @@ make_dir_parents_private (char const *const_dir, size_t src_offset,
 
               /* This component does not exist.  We must set
                  *new_dst and new->st.st_mode inside this loop because,
-                 for example, in the command `cp --parents ../a/../b/c e_dir',
+                 for example, in the command 'cp --parents ../a/../b/c e_dir',
                  make_dir_parents_private creates only e_dir/../a if
                  ./b already exists. */
               *new_dst = true;
@@ -532,7 +531,7 @@ make_dir_parents_private (char const *const_dir, size_t src_offset,
             *new_dst = false;
           *slash++ = '/';
 
-          /* Avoid unnecessary calls to `stat' when given
+          /* Avoid unnecessary calls to 'stat' when given
              file names containing multiple adjacent slashes.  */
           while (*slash == '/')
             slash++;
@@ -624,8 +623,8 @@ do_copy (int n_files, char **file, const char *target_directory,
   if (target_directory)
     {
       /* cp file1...filen edir
-         Copy the files `file1' through `filen'
-         to the existing directory `edir'. */
+         Copy the files 'file1' through 'filen'
+         to the existing directory 'edir'. */
       int i;
 
       /* Initialize these hash tables only if we'll need them.
@@ -654,15 +653,15 @@ do_copy (int n_files, char **file, const char *target_directory,
             {
               char *arg_no_trailing_slash;
 
-              /* Use `arg' without trailing slashes in constructing destination
+              /* Use 'arg' without trailing slashes in constructing destination
                  file names.  Otherwise, we can end up trying to create a
-                 directory via `mkdir ("dst/foo/"...', which is not portable.
+                 directory via 'mkdir ("dst/foo/"...', which is not portable.
                  It fails, due to the trailing slash, on at least
                  NetBSD 1.[34] systems.  */
               ASSIGN_STRDUPA (arg_no_trailing_slash, arg);
               strip_trailing_slashes (arg_no_trailing_slash);
 
-              /* Append all of `arg' (minus any trailing slash) to `dest'.  */
+              /* Append all of 'arg' (minus any trailing slash) to 'dest'.  */
               dst_name = file_name_concat (target_directory,
                                            arg_no_trailing_slash,
                                            &arg_in_concat);
@@ -679,10 +678,10 @@ do_copy (int n_files, char **file, const char *target_directory,
           else
             {
               char *arg_base;
-              /* Append the last component of `arg' to `target_directory'.  */
+              /* Append the last component of 'arg' to 'target_directory'.  */
 
               ASSIGN_BASENAME_STRDUPA (arg_base, arg);
-              /* For `cp -R source/.. dest', don't copy into `dest/..'. */
+              /* For 'cp -R source/.. dest', don't copy into 'dest/..'. */
               dst_name = (STREQ (arg_base, "..")
                           ? xstrdup (target_directory)
                           : file_name_concat (target_directory, arg_base,
@@ -735,7 +734,7 @@ do_copy (int n_files, char **file, const char *target_directory,
       /* When the force and backup options have been specified and
          the source and destination are the same name for an existing
          regular file, convert the user's command, e.g.,
-         `cp --force --backup foo foo' to `cp --force foo fooSUFFIX'
+         'cp --force --backup foo foo' to 'cp --force foo fooSUFFIX'
          where SUFFIX is determined by any version control options used.  */
 
       if (x->unlink_dest_after_failed_open
@@ -746,9 +745,9 @@ do_copy (int n_files, char **file, const char *target_directory,
           static struct cp_options x_tmp;
 
           new_dest = find_backup_file_name (dest, x->backup_type);
-          /* Set x->backup_type to `no_backups' so that the normal backup
+          /* Set x->backup_type to 'no_backups' so that the normal backup
              mechanism is not used when performing the actual copy.
-             backup_type must be set to `no_backups' only *after* the above
+             backup_type must be set to 'no_backups' only *after* the above
              call to find_backup_file_name -- that function uses
              backup_type to determine the suffix it applies.  */
           x_tmp = *x;
@@ -835,7 +834,7 @@ decode_preserve_arg (char const *arg, struct cp_options *x, bool on_off)
       PRESERVE_OWNERSHIP, PRESERVE_LINK, PRESERVE_CONTEXT, PRESERVE_XATTR,
       PRESERVE_ALL
     };
-  /* Valid arguments to the `--preserve' option. */
+  /* Valid arguments to the '--preserve' option. */
   static char const* const preserve_args[] =
     {
       "mode", "timestamps",
@@ -1021,7 +1020,7 @@ main (int argc, char **argv)
         case PRESERVE_ATTRIBUTES_OPTION:
           if (optarg == NULL)
             {
-              /* Fall through to the case for `p' below.  */
+              /* Fall through to the case for 'p' below.  */
             }
           else
             {
