@@ -30,7 +30,7 @@
 #include "xstrtol.h"
 #include "c-ctype.h"
 
-/* The official name of this program (e.g., no `g' prefix).  */
+/* The official name of this program (e.g., no 'g' prefix).  */
 #define PROGRAM_NAME "stdbuf"
 #define LIB_NAME "libstdbuf.so" /* FIXME: don't hardcode  */
 
@@ -84,8 +84,7 @@ void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-             program_name);
+    emit_try_help ();
   else
     {
       printf (_("Usage: %s OPTION... COMMAND\n"), program_name);
@@ -104,10 +103,10 @@ Mandatory arguments to long options are mandatory for short options too.\n\
       fputs (HELP_OPTION_DESCRIPTION, stdout);
       fputs (VERSION_OPTION_DESCRIPTION, stdout);
       fputs (_("\n\
-If MODE is `L' the corresponding stream will be line buffered.\n\
+If MODE is 'L' the corresponding stream will be line buffered.\n\
 This option is invalid with standard input.\n"), stdout);
       fputs (_("\n\
-If MODE is `0' the corresponding stream will be unbuffered.\n\
+If MODE is '0' the corresponding stream will be unbuffered.\n\
 "), stdout);
       fputs (_("\n\
 Otherwise MODE is a number which may be followed by one of the following:\n\
@@ -116,10 +115,10 @@ In this case the corresponding stream will be fully buffered with the buffer\n\
 size set to MODE bytes.\n\
 "), stdout);
       fputs (_("\n\
-NOTE: If COMMAND adjusts the buffering of its standard streams (`tee' does\n\
-for e.g.) then that will override corresponding settings changed by `stdbuf'.\n\
-Also some filters (like `dd' and `cat' etc.) don't use streams for I/O,\n\
-and are thus unaffected by `stdbuf' settings.\n\
+NOTE: If COMMAND adjusts the buffering of its standard streams ('tee' does\n\
+for e.g.) then that will override corresponding settings changed by 'stdbuf'.\n\
+Also some filters (like 'dd' and 'cat' etc.) don't use streams for I/O,\n\
+and are thus unaffected by 'stdbuf' settings.\n\
 "), stdout);
       emit_ancillary_info ();
     }
