@@ -1,5 +1,5 @@
 /* tsort - topological sort.
-   Copyright (C) 1998-2005, 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 1998-2012 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
 #include "readtokens.h"
 #include "stdio--.h"
 
-/* The official name of this program (e.g., no `g' prefix).  */
+/* The official name of this program (e.g., no 'g' prefix).  */
 #define PROGRAM_NAME "tsort"
 
 #define AUTHORS proper_name ("Mark Kettenis")
@@ -63,7 +63,7 @@ struct item
 /* The head of the sorted list.  */
 static struct item *head = NULL;
 
-/* The tail of the list of `zeros', strings that have no predecessors.  */
+/* The tail of the list of 'zeros', strings that have no predecessors.  */
 static struct item *zeros = NULL;
 
 /* Used for loop detection.  */
@@ -76,8 +76,7 @@ void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-             program_name);
+    emit_try_help ();
   else
     {
       printf (_("\
