@@ -1,5 +1,5 @@
 /* GNU's users.
-   Copyright (C) 1992-2005, 2007-2012 Free Software Foundation, Inc.
+   Copyright (C) 1992-2012 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #include "quote.h"
 #include "readutmp.h"
 
-/* The official name of this program (e.g., no `g' prefix).  */
+/* The official name of this program (e.g., no 'g' prefix).  */
 #define PROGRAM_NAME "users"
 
 #define AUTHORS \
@@ -99,8 +99,7 @@ void
 usage (int status)
 {
   if (status != EXIT_SUCCESS)
-    fprintf (stderr, _("Try `%s --help' for more information.\n"),
-             program_name);
+    emit_try_help ();
   else
     {
       printf (_("Usage: %s [OPTION]... [FILE]\n"), program_name);
